#ifndef NT2_INCLUDE_FUNCTIONS_POLY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLY_HPP_INCLUDED

#include <nt2/linalg/include/functions/poly.hpp>

#endif
